package com.citygis.config;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.jdbc.DataSourceBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.jdbc.core.JdbcTemplate;

import javax.sql.DataSource;

/**
 * @Package com.citygis.config
 * @Author zyl
 * @Date 2024/1/31 0031 15:41
 * @description: 数据源配置
 */
@Configuration
public class DataSourceConfig {


    /**
     * 病媒数据源
     *
     * @return
     */
    @Primary
    @Bean(name = "ds1DataSource")
    @ConfigurationProperties(prefix = "spring.datasource.ds1")
    public DataSource ds1DataSource() {
        return DataSourceBuilder.create().build();
    }

    /**
     * 水质数据源
     *
     * @return
     */
    @Bean(name = "ds2DataSource")
    @ConfigurationProperties(prefix = "spring.datasource.ds2")
    public DataSource ds2DataSource() {
        return DataSourceBuilder.create().build();
    }

    /**
     * 病例数据源
     *
     * @return
     */
    @Bean(name = "ds3DataSource")
    @ConfigurationProperties(prefix = "spring.datasource.ds3")
    public DataSource ds3DataSource() {
        return DataSourceBuilder.create().build();
    }

    /**
     * gis数据源
     *
     * @return
     */
    @Bean(name = "ds4DataSource")
    @ConfigurationProperties(prefix = "spring.datasource.ds4")
    public DataSource ds4DataSource() {
        return DataSourceBuilder.create().build();
    }

//    /**
//     * 公式公告数据源
//     * @return
//     */
//    @Bean(name = "ds5DataSource")
//    @ConfigurationProperties(prefix = "datasource.ds5")
//    public DataSource ds5DataSource() {
//        return DataSourceBuilder.create().build();
//    }

    @Bean(name = "ds1JdbcTemplate")
    public JdbcTemplate ds1JdbcTemplate(@Qualifier("ds1DataSource") DataSource ds1DataSource) {
        return new JdbcTemplate(ds1DataSource);
    }

    @Bean(name = "ds2JdbcTemplate")
    public JdbcTemplate ds2JdbcTemplate(@Qualifier("ds2DataSource") DataSource ds2DataSource) {
        return new JdbcTemplate(ds2DataSource);
    }

    @Bean(name = "ds3JdbcTemplate")
    public JdbcTemplate ds3JdbcTemplate(@Qualifier("ds3DataSource") DataSource ds3DataSource) {
        return new JdbcTemplate(ds3DataSource);
    }

    @Bean(name = "ds4JdbcTemplate")
    public JdbcTemplate ds4JdbcTemplate(@Qualifier("ds4DataSource") DataSource ds4DataSource) {
        return new JdbcTemplate(ds4DataSource);
    }

//    @Bean(name = "ds5JdbcTemplate")
//    public JdbcTemplate ds5JdbcTemplate(@Qualifier("ds5DataSource") DataSource ds5DataSource) {
//        return new JdbcTemplate(ds5DataSource);
//    }

}
