package com.citygis.controller;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.citygis.service.DataSourceService;
import com.citygis.service.LoginServiceImpl;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.List;
import java.util.Map;

/**
 * @Package com.citygis.controller
 * @Author zyl
 * @Date 2024/1/25 0025 13:39
 * @description: 登录和获取用户信息
 */
@RestController
@CrossOrigin
public class LoginServicController {

    private final static Logger log = LoggerFactory.getLogger(LoginServicController.class);

    @Resource
    LoginServiceImpl loginService;

    @Resource
    private DataSourceService dataSourceService;

    public static final String access_token = "access_token";

    /**
     * 单点登录，页面初始化调用
     *
     * @param request
     * @param response
     * @param serviceType
     * @throws IOException
     */
    @RequestMapping("/login")
    public void Page_Load(HttpServletRequest request,
                          HttpServletResponse response,
                          @RequestParam("serviceType") Integer serviceType) throws IOException {
        loginService.page_Load(request, response, serviceType);
    }

    /**
     * 获取登录用户信息
     *
     * 暂未使用
     * @param code
     * @param serviceType
     * @return
     * @throws UnsupportedEncodingException
     */
    @RequestMapping(value = "/callback")
    @ResponseBody
    public String callback(@RequestParam("code") String code,
                           @RequestParam("serviceType") Integer serviceType) throws UnsupportedEncodingException {
        // 获取accessToken
        String data = loginService.getAccessToken(code, serviceType);

        log.info("data--->" + data);

        JSONObject jsonObject = JSONObject.parseObject(data);
        String accessToken = jsonObject.getString(access_token);

        log.info("accessToken--->" + accessToken);

        return "{\"success\":\"true\",\"Message\":\"{\"data\":" + loginService.getUserInfo(accessToken) + "}\"}";
    }

    /**
     * 获取用户信息详情
     *
     * @param code
     * @param serviceType
     * @return
     * @throws UnsupportedEncodingException
     */
    @RequestMapping(value = "/user")
    @ResponseBody
    public String user(@RequestParam("code") String code,
                       @RequestParam("serviceType") Integer serviceType) throws UnsupportedEncodingException {
        // 获取accessToken
        String data = loginService.getAccessToken(code, serviceType);

        log.info("data--->" + data);

        JSONObject jsonObject = JSONObject.parseObject(data);
        String accessToken = jsonObject.getString(access_token);

        log.info("accessToken--->" + accessToken);

        //用accessToken获取用户信息
        String userInfo = loginService.getUserInfo(accessToken);
        List<Map<String, Object>> user = getUser(userInfo, serviceType);
        Object jsonUser = JSON.toJSON(user);

        log.info("登录用户信息--->" + jsonUser);

        return "{\"success\":\"true\",\"Message\":" + jsonUser + "}";
    }

    /**
     * 查询用户信息
     *
     * @param user
     * @param serviceType
     * @return
     */
    public List<Map<String, Object>> getUser(String user, Integer serviceType) {
        JSONObject jsonObject = JSONObject.parseObject(user);
        Object attributes = jsonObject.get("attributes");
        String jsonString = JSON.toJSONString(attributes);
        String name = JSONObject.parseObject(jsonString).getString("account_no");
        List<Map<String, Object>> maps = null;

        log.info("登录用户名--->" + name);

        //根据serviceType查询不同数据源获取用户详细信息
        switch (serviceType) {
            case 0:
                maps = dataSourceService.queryFromBM(name);
                break;
            case 1:
                maps = dataSourceService.queryFromSZ(name);
                break;
            case 2:
                maps = dataSourceService.queryFromBL(name);
                break;
            case 3:
                maps = dataSourceService.queryFromGIS(name);
                break;
            default:
                break;
        }

        return maps;

    }

}
