package com.citygis.service;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @Package com.citygis.service
 * @Author zyl
 * @Date 2024/1/31 0031 15:42
 * @description: 用户信息查询
 */
@Service
public class DataSourceService {

    private final static Logger log = LoggerFactory.getLogger(DataSourceService.class);

    /**
     * 病媒
     */
    private final JdbcTemplate ds1JdbcTemplate;
    /**
     * 水质
     */
    private final JdbcTemplate ds2JdbcTemplate;
    /**
     * 病例
     */
    private final JdbcTemplate ds3JdbcTemplate;
    /**
     * gis
     */
    private final JdbcTemplate ds4JdbcTemplate;

    public DataSourceService(@Qualifier("ds1JdbcTemplate") JdbcTemplate ds1JdbcTemplate,
                             @Qualifier("ds2JdbcTemplate") JdbcTemplate ds2JdbcTemplate,
                             @Qualifier("ds3JdbcTemplate") JdbcTemplate ds3JdbcTemplate,
                             @Qualifier("ds4JdbcTemplate") JdbcTemplate ds4JdbcTemplate) {
        this.ds1JdbcTemplate = ds1JdbcTemplate;
        this.ds2JdbcTemplate = ds2JdbcTemplate;
        this.ds3JdbcTemplate = ds3JdbcTemplate;
        this.ds4JdbcTemplate = ds4JdbcTemplate;
    }

    /**
     * 查询病媒数据库
     *
     * @param name
     * @return
     */
    public List<Map<String, Object>> queryFromBM(String name) {

        log.info("病媒查询--->"+name);

        return ds1JdbcTemplate.queryForList("SELECT  [UID],[UFullName] ,[UAccount] ,[UNumber] ,[OID],[OName],[CID] ,[CName],[U_ROLE] ," +
                "[PRIVACY],b.R_CONTENT,c.[D_NAMEPATH] FROM [dbo].[ROLE_INFO] b,[dbo].[T_USER] a left join [dbo].[DEPARTMENT_INFO] c " +
                "on a.[OName]=c.[D_NAME] and C.D_TYPE='科室' where [U_ROLE] =b.R_ID and UState=1 and [UAccount]='" + name + "'");
    }


    /**
     * 查询水质数据库
     *
     * @param name
     * @return
     */
    public List<Map<String, Object>> queryFromSZ(String name) {

        log.info("水质查询--->"+name);

        return ds2JdbcTemplate.queryForList("SELECT  [UID],[UFullName] ,[UAccount] ,[UNumber] ,[OID],[OName],[CID] ,[CName],[U_ROLE] ," +
                "[PRIVACY],b.R_CONTENT,c.[D_NAMEPATH] FROM [dbo].[ROLE_INFO] b,[dbo].[T_USER] a left join [dbo].[DEPARTMENT_INFO] c " +
                "on a.[OName]=c.[D_NAME] and C.D_TYPE='科室' where [U_ROLE] =b.R_ID and UState=1 and [UAccount]='" + name + "'");
    }


    /**
     * 查询病例数据库
     *
     * @param name
     * @return
     */
    public List<Map<String, Object>> queryFromBL(String name) {

        log.info("病例查询--->"+name);

        return ds3JdbcTemplate.queryForList("SELECT  [UID],[UFullName] ,[UAccount] ,[UNumber] ,[OID],[OName],[CID] ,[CName],[U_ROLE] ," +
                "[PRIVACY],b.R_CONTENT,c.[D_NAMEPATH] FROM [dbo].[ROLE_INFO] b,[dbo].[T_USER] a left join [dbo].[DEPARTMENT_INFO] c " +
                "on a.[OName]=c.[D_NAME] and C.D_TYPE='科室' where [U_ROLE] =b.R_ID and UState=1 and [UAccount]='" + name + "'");
    }


    /**
     * 查询gis数据库
     *
     * @param name
     * @return
     */
    public List<Map<String, Object>> queryFromGIS(String name) {

        log.info("gis查询--->"+name);

        return ds4JdbcTemplate.queryForList("SELECT  [UID],[UFullName] ,[UAccount] ,[UNumber] ,[OID],[OName],[CID] ,[CName],[U_ROLE] ," +
                "[PRIVACY],b.R_CONTENT,c.[D_NAMEPATH] FROM [dbo].[ROLE_INFO] b,[dbo].[T_USER] a left join [dbo].[DEPARTMENT_INFO] c " +
                "on a.[OName]=c.[D_NAME] and C.D_TYPE='科室' where [U_ROLE] =b.R_ID and UState=1 and [UAccount]='" + name + "'");
    }

}
