package com.citygis.service;

import cn.hutool.http.HttpUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Package com.citygis.service
 * @Author zyl
 * @Date 2024/1/25 0025 13:38
 * @description: 登录
 */
@ConfigurationProperties(prefix = "login-url")
@Service
public class LoginServiceImpl {

    private final static Logger log = LoggerFactory.getLogger(LoginServiceImpl.class);

    /**
     * 变量值从配置文件获取
     */
    private String ssoRet;

    private String tokenYZ;

    private String accesstoken;

    private String gisURLs;

    private String client_ids;

    private String appCodes;

    private String ssoHost;

    private String clientSecrets;

    private String ssoToken;

    public String getSsoToken() {
        return ssoToken;
    }

    public void setSsoToken(String ssoToken) {
        this.ssoToken = ssoToken;
    }

    public String getClientSecrets() {
        return clientSecrets;
    }

    public void setClientSecrets(String clientSecrets) {
        this.clientSecrets = clientSecrets;
    }

    public String getSsoHost() {
        return ssoHost;
    }

    public void setSsoHost(String ssoHost) {
        this.ssoHost = ssoHost;
    }

    public String getAccesstoken() {
        return accesstoken;
    }

    public void setAccesstoken(String accesstoken) {
        this.accesstoken = accesstoken;
    }

    public String getTokenYZ() {
        return tokenYZ;
    }

    public void setTokenYZ(String tokenYZ) {
        this.tokenYZ = tokenYZ;
    }

    public String getSsoRet() {
        return ssoRet;
    }

    public void setSsoRet(String ssoRet) {
        this.ssoRet = ssoRet;
    }

    public String getGisURLs() {
        return gisURLs;
    }

    public void setGisURLs(String gisURLs) {
        this.gisURLs = gisURLs;
    }

    public String getClient_ids() {
        return client_ids;
    }

    public void setClient_ids(String client_ids) {
        this.client_ids = client_ids;
    }

    public String getAppCodes() {
        return appCodes;
    }

    public void setAppCodes(String appCodes) {
        this.appCodes = appCodes;
    }


    /**
     * 配置文件中的参数存在多个的话，通过下面这个方法解析到数组
     *
     * @return
     */
    private List<Map<String, String>> t() {
        List<Map<String, String>> list = new ArrayList<>();

        String[] splitAppCodes = appCodes.split(",");
        String[] splitGisURLs = gisURLs.split(",");
        String[] splitClient_ids = client_ids.split(",");
        String[] splitClientSecrets = clientSecrets.split(",");

        for (int i = 0; i < splitAppCodes.length; i++) {
            Map<String, String> map = new HashMap<>();
            map.put(String.valueOf(i), splitAppCodes[i]);
            map.put(i + "gisUrl", splitGisURLs[i]);
            map.put(i + "clientid", splitClient_ids[i]);
            map.put(i + "clientSecret", splitClientSecrets[i]);
            list.add(map);
        }
        return list;
    }

    /**
     * 登录跳转，根据serviceType来决定重定向到那个系统
     * serviceType：0 病媒系统
     * 1  水质系统
     * 2  病例系统
     * 3  gis共享平台
     *
     * @param request
     * @param response
     * @param serviceType
     * @throws IOException
     */
    public void page_Load(HttpServletRequest request, HttpServletResponse response, Integer serviceType) throws IOException {

        String appCode = null;

        String gisURL = null;

        String client_id = null;

        //根据serviceType获取跳转到那个系统的所有值
        for (Map<String, String> st : t()) {
            for (String key : st.keySet()) {
                if (key.equals(serviceType.toString())) {
                    appCode = st.get(serviceType.toString());
                }
                if (key.equals(serviceType + "gisUrl")) {
                    gisURL = st.get(serviceType + "gisUrl");
                }
                if (key.equals(serviceType + "clientid")) {
                    client_id = st.get(serviceType + "clientid");
                }
            }
        }

        //拼接url，ssoRet为派拉请求登陆认证地址，redirect_uri为跳转应用地址
        String returnURL = ssoRet +
                "client_id=" + client_id + "&" +
                "response_type=code" +
                "&redirect_uri=" + URLEncoder.encode(gisURL, StandardCharsets.UTF_8.toString()) +
                "&oauth_timestamp=" + System.currentTimeMillis();

        log.info("成功--->" + appCode + "--->" + returnURL);

        response.sendRedirect(returnURL);
        return;
    }


    /**
     * 获取token
     *
     * @param code
     * @param serviceType
     * @return
     * @throws UnsupportedEncodingException
     */
    public String getAccessToken(String code, Integer serviceType) throws UnsupportedEncodingException {

        String appCode = null;

        String gisURL = null;

        String client_id = null;

        String clientSecret = null;

        //根据serviceType获取制定系统的所有值
        for (Map<String, String> st : t()) {
            for (String key : st.keySet()) {
                if (key.equals(serviceType.toString())) {
                    appCode = st.get(serviceType.toString());
                }
                if (key.equals(serviceType + "gisUrl")) {
                    gisURL = st.get(serviceType + "gisUrl");
                }
                if (key.equals(serviceType + "clientid")) {
                    client_id = st.get(serviceType + "clientid");
                }
                if (key.equals(serviceType + "clientSecret")) {
                    clientSecret = st.get(serviceType + "clientSecret");
                }
            }
        }

        //添加URL参数，注意生成的token所用的code只能使用一次
        Map<String, String> params = new HashMap<>();
        params.put("grant_type", "authorization_code");
        params.put("oauth_timestamp", String.valueOf(System.currentTimeMillis()));
        params.put("client_id", client_id);
        params.put("client_secret", clientSecret);
        params.put("code", code);
        params.put("redirect_uri", URLEncoder.encode(gisURL, StandardCharsets.UTF_8.toString()));
        StringBuilder tokenParam = new StringBuilder();
        //拼接参数
        for (String key : params.keySet()) {
            if (tokenParam.length() == 0) {
                tokenParam.append(key).append("=").append(params.get(key));
            } else {
                tokenParam.append("&").append(key).append("=").append(params.get(key));
            }
        }
        //url和参数拼接
        String url = ssoToken + tokenParam;

        log.info("获取token--->" + url);

        return HttpUtil.createPost(url).execute().body();
    }

    /**
     * 获取用户信息
     *
     * @param accessToken token
     */

    public String getUserInfo(String accessToken) {
        Map<String, String> params = new HashMap<>();
        params.put("access_token", accessToken);
        StringBuilder tokenParam = new StringBuilder();
        for (String key : params.keySet()) {
            if (tokenParam.length() == 0) {
                tokenParam.append(key).append("=").append(params.get(key));
            } else {
                tokenParam.append("&").append(key).append("=").append(params.get(key));
            }
        }
        String url = ssoHost + tokenParam;

        log.info("获取用户--->" + url);

        return HttpUtil.createGet(url).execute().body();
    }
}
