package com.citygis.service;

import com.auth0.jwt.JWT;
import com.auth0.jwt.algorithms.Algorithm;
import com.citygis.utils.SSLUtils;
import org.apache.http.HttpEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.BufferedHttpEntity;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.util.EntityUtils;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import java.io.IOException;
import java.net.URISyntaxException;
import java.util.Date;
import java.util.UUID;

/**
 * @Package com.citygis.service
 * @Author zyl
 * @Date 2024/1/29 0029 9:45
 * @description: 同步派拉用户信息
 */
@ConfigurationProperties(prefix = "user-synchronous")
@Service
public class UserSynchronousServiceImpl {
    private String url;

    private String appID;

    private String appSecret;

    public String getAppID() {
        return appID;
    }

    public void setAppID(String appID) {
        this.appID = appID;
    }

    public String getAppSecret() {
        return appSecret;
    }

    public void setAppSecret(String appSecret) {
        this.appSecret = appSecret;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }


    private RestTemplate restTemplate;

    public void UrlForwardingController(RestTemplate restTemplate) {
        this.restTemplate = restTemplate;
    }

    public String breaerToken() {
        System.out.println("appID--->" + appID + "---appSecret--->" + appSecret);

        String token = JWT.create().withIssuer(appID)
                .withIssuedAt(new Date())
                .withJWTId(UUID.randomUUID().toString())
                .sign(Algorithm.HMAC256(appSecret));

        token = String.join(" ", "Bearer", token);

        return token;
    }

    public void UserSynchronous() throws URISyntaxException, IOException {

        String s = null;

        long timestamp = System.currentTimeMillis();

        String params = "{\"size\":\"10\",\"page\":\"1\",\"startTime\":" + timestamp + "}";

        CloseableHttpClient httpClient = SSLUtils.createSSLClientDefault();
        // 创建Post请求
        HttpPost httpPost = new HttpPost(url);
        System.out.println("用户信息--->" + url);
        String token = this.breaerToken();

//        添加参数
        StringEntity entity = new StringEntity(params, "UTF-8");
        httpPost.setEntity(entity);

        httpPost.setHeader("Authorization", token);
        httpPost.setHeader("Content-Type", "application/json");

        // 响应模型
        CloseableHttpResponse response = null;
        try {
            // 由客户端执行(发送)Post请求
            response = httpClient.execute(httpPost);

            // 从响应模型中获取响应实体
            HttpEntity responseEntity = response.getEntity();
            responseEntity = new BufferedHttpEntity(responseEntity);

            System.out.println("响应状态为:" + response.getStatusLine());
            if (responseEntity != null) {
                System.out.println("响应内容长度为:" + responseEntity.getContentLength());
                s = EntityUtils.toString(responseEntity, "UTF-8");
                System.out.println(s);
            }
        } catch (Exception e) {
            e.getMessage();
        } finally {

            // 释放资源
            if (httpClient != null) {
                httpClient.close();
            }
        }

    }

}
